#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class jrRangeAlert : Indicator
    {
        #region Variables
        // Wizard generated variables
        // User defined variables (add any user defined variables below)
		private int alertpips = 10;	
		private string alertfile = "C:\\chime.wav";
		
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= true;
            PriceTypeSupported	= false;
			Print(TickSize.ToString());
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			double range = Instrument.MasterInstrument.Round2TickSize(High[0]-Low[0]);
			
			if (range>=alertpips*TickSize)
			{				
				double ap = alertpips*TickSize;
				PlaySound(alertfile);			
				Print(Time[0].ToString() + ", " + High[0].ToString()+ ", " + Low[0].ToString() + ", " + range.ToString()); 
			}
        }

        #region Properties
		
		[Description("Number of Pips to signal alert")]
        [Category("Parameters")]
        public int AlertPips
        {
            get { return alertpips; }
            set { alertpips = Math.Max(1, value); }
        }
		
		[Description("Location of sound file for alert")]
        [Category("Parameters")]
        public string AlertFile
        {
            get { return alertfile; }
            set { alertfile = value; }
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private jrRangeAlert[] cachejrRangeAlert = null;

        private static jrRangeAlert checkjrRangeAlert = new jrRangeAlert();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public jrRangeAlert jrRangeAlert(string alertFile, int alertPips)
        {
            return jrRangeAlert(Input, alertFile, alertPips);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public jrRangeAlert jrRangeAlert(Data.IDataSeries input, string alertFile, int alertPips)
        {
            checkjrRangeAlert.AlertFile = alertFile;
            alertFile = checkjrRangeAlert.AlertFile;
            checkjrRangeAlert.AlertPips = alertPips;
            alertPips = checkjrRangeAlert.AlertPips;

            if (cachejrRangeAlert != null)
                for (int idx = 0; idx < cachejrRangeAlert.Length; idx++)
                    if (cachejrRangeAlert[idx].AlertFile == alertFile && cachejrRangeAlert[idx].AlertPips == alertPips && cachejrRangeAlert[idx].EqualsInput(input))
                        return cachejrRangeAlert[idx];

            jrRangeAlert indicator = new jrRangeAlert();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.AlertFile = alertFile;
            indicator.AlertPips = alertPips;
            indicator.SetUp();

            jrRangeAlert[] tmp = new jrRangeAlert[cachejrRangeAlert == null ? 1 : cachejrRangeAlert.Length + 1];
            if (cachejrRangeAlert != null)
                cachejrRangeAlert.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cachejrRangeAlert = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.jrRangeAlert jrRangeAlert(string alertFile, int alertPips)
        {
            return _indicator.jrRangeAlert(Input, alertFile, alertPips);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.jrRangeAlert jrRangeAlert(Data.IDataSeries input, string alertFile, int alertPips)
        {
            return _indicator.jrRangeAlert(input, alertFile, alertPips);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.jrRangeAlert jrRangeAlert(string alertFile, int alertPips)
        {
            return _indicator.jrRangeAlert(Input, alertFile, alertPips);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.jrRangeAlert jrRangeAlert(Data.IDataSeries input, string alertFile, int alertPips)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.jrRangeAlert(input, alertFile, alertPips);
        }

    }
}
#endregion
